@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2010  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -31,14 +31,13 @@
 #include <netinet/in.h>
 
 #include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
 #include <bluetooth/bnep.h>
 #include <bluetooth/sdp.h>
 
 #include <glib.h>
 #include <gdbus.h>
 
-#include "logging.h"
+#include "log.h"
 #include "glib-helper.h"
 #include "btio.h"
 #include "dbus-common.h"
@@ -82,7 +81,6 @@ struct __service_16 {
 } __attribute__ ((packed));
 
 static DBusConnection *connection = NULL;
-static const char *prefix = NULL;
 static GSList *peers = NULL;
 
 static struct network_peer *find_peer(GSList *list, const char *path)
@@ -142,7 +140,7 @@ static inline DBusMessage *connection_attempt_failed(DBusMessage *msg,
 {
 	return g_dbus_create_error(msg,
 				ERROR_INTERFACE ".ConnectionAttemptFailed",
-				err ? err : "Connection attempt failed");
+				"%s", err ? err : "Connection attempt failed");
 }
 
 static gboolean bnep_watchdog_cb(GIOChannel *chan, GIOCondition cond,
@@ -157,12 +155,13 @@ static gboolean bnep_watchdog_cb(GIOChannel *chan, GIOCondition cond,
 					NETWORK_PEER_INTERFACE, "Connected",
 					DBUS_TYPE_BOOLEAN, &connected);
 		emit_property_changed(connection, nc->peer->path,
-					NETWORK_PEER_INTERFACE, "Device",
+					NETWORK_PEER_INTERFACE, "Interface",
 					DBUS_TYPE_STRING, &property);
 		emit_property_changed(connection, nc->peer->path,
 					NETWORK_PEER_INTERFACE, "UUID",
 					DBUS_TYPE_STRING, &property);
 		device_remove_disconnect_watch(nc->peer->device, nc->dc_id);
+		nc->dc_id = 0;
 		if (nc->watch) {
 			g_dbus_remove_watch(connection, nc->watch);
 			nc->watch = 0;
@@ -173,8 +172,8 @@ static gboolean bnep_watchdog_cb(GIOChannel *chan, GIOCondition cond,
 
 	bnep_if_down(nc->dev);
 	nc->state = DISCONNECTED;
-	memset(nc->dev, 0, 16);
-	strncpy(nc->dev, prefix, sizeof(nc->dev) - 1);
+	memset(nc->dev, 0, sizeof(nc->dev));
+	strcpy(nc->dev, "bnep%d");
 
 	return FALSE;
 }
@@ -288,7 +287,7 @@ static gboolean bnep_setup_cb(GIOChannel *chan, GIOCondition cond,
 		goto failed;
 	}
 
-	bnep_if_up(nc->dev, nc->id);
+	bnep_if_up(nc->dev);
 	pdev = nc->dev;
 	uuid = bnep_uuid(nc->id);
 
@@ -301,7 +300,7 @@ static gboolean bnep_setup_cb(GIOChannel *chan, GIOCondition cond,
 				NETWORK_PEER_INTERFACE, "Connected",
 				DBUS_TYPE_BOOLEAN, &connected);
 	emit_property_changed(connection, nc->peer->path,
-				NETWORK_PEER_INTERFACE, "Device",
+				NETWORK_PEER_INTERFACE, "Interface",
 				DBUS_TYPE_STRING, &pdev);
 	emit_property_changed(connection, nc->peer->path,
 				NETWORK_PEER_INTERFACE, "UUID",
@@ -501,9 +500,9 @@ static DBusMessage *connection_get_properties(DBusConnection *conn,
 	connected = nc ? TRUE : FALSE;
 	dict_append_entry(&dict, "Connected", DBUS_TYPE_BOOLEAN, &connected);
 
-	/* Device */
+	/* Interface */
 	property = nc ? nc->dev : "";
-	dict_append_entry(&dict, "Device", DBUS_TYPE_STRING, &property);
+	dict_append_entry(&dict, "Interface", DBUS_TYPE_STRING, &property);
 
 	/* UUID */
 	property = nc ? bnep_uuid(nc->id) : "";
@@ -516,6 +515,9 @@ static DBusMessage *connection_get_properties(DBusConnection *conn,
 
 static void connection_free(struct network_conn *nc)
 {
+	if (nc->dc_id)
+		device_remove_disconnect_watch(nc->peer->device, nc->dc_id);
+
 	connection_destroy(connection, nc);
 
 	g_free(nc);
@@ -535,7 +537,7 @@ static void path_unregister(void *data)
 {
 	struct network_peer *peer = data;
 
-	debug("Unregistered interface %s on path %s",
+	DBG("Unregistered interface %s on path %s",
 		NETWORK_PEER_INTERFACE, peer->path);
 
 	peers = g_slist_remove(peers, peer);
@@ -599,7 +601,7 @@ static struct network_peer *create_peer(struct btd_device *device,
 		return NULL;
 	}
 
-	debug("Registered interface %s on path %s",
+	DBG("Registered interface %s on path %s",
 		NETWORK_PEER_INTERFACE, path);
 
 	return peer;
@@ -628,8 +630,8 @@ int connection_register(struct btd_device *device, const char *path,
 
 	nc = g_new0(struct network_conn, 1);
 	nc->id = id;
-	memset(nc->dev, 0, 16);
-	strncpy(nc->dev, prefix, sizeof(nc->dev) - 1);
+	memset(nc->dev, 0, sizeof(nc->dev));
+	strcpy(nc->dev, "bnep%d");
 	nc->state = DISCONNECTED;
 	nc->peer = peer;
 
@@ -638,17 +640,15 @@ int connection_register(struct btd_device *device, const char *path,
 	return 0;
 }
 
-int connection_init(DBusConnection *conn, const char *iface_prefix)
+int connection_init(DBusConnection *conn)
 {
 	connection = dbus_connection_ref(conn);
-	prefix = iface_prefix;
 
 	return 0;
 }
 
-void connection_exit()
+void connection_exit(void)
 {
 	dbus_connection_unref(connection);
 	connection = NULL;
-	prefix = NULL;
 }
