@@ -55,6 +55,9 @@ static struct controller_info {
 	uint8_t type;
 	bdaddr_t bdaddr;
 	uint8_t features[8];
+	uint16_t manufacturer;
+	uint8_t hci_ver;
+	uint16_t hci_rev;
 	gboolean enabled;
 	uint8_t mode;
 } *controllers = NULL;
@@ -238,9 +241,14 @@ static void read_info_complete(int sk, void *buf, size_t len)
 	info->type = rp->type;
 	bacpy(&info->bdaddr, &rp->bdaddr);
 	memcpy(info->features, rp->features, 8);
+	info->manufacturer = btohs(bt_get_unaligned(&rp->manufacturer));
+	info->hci_ver = rp->hci_ver;
+	info->hci_rev = btohs(bt_get_unaligned(&rp->hci_rev));
 
 	ba2str(&info->bdaddr, addr);
-	DBG("hci%u addr %s type %u", index, addr, info->type);
+	DBG("hci%u addr %s type %u manufacturer %d hci ver %d:%d",
+				index, addr, info->type, info->manufacturer,
+				info->hci_ver, info->hci_rev);
 
 	read_mode(sk, index);
 }
@@ -276,6 +284,9 @@ static void read_mode_complete(int sk, void *buf, size_t len)
 	DBG("hci%u enabled %u mode %u", index, info->enabled, info->mode);
 
 	manager_register_adapter(index, info->enabled);
+
+	if (info->enabled)
+		manager_start_adapter(index);
 }
 
 static void mgmt_cmd_complete(int sk, void *buf, size_t len)
@@ -552,12 +563,6 @@ static int mgmt_set_name(int index, const char *name)
 	return -ENOSYS;
 }
 
-static int mgmt_read_name(int index)
-{
-	DBG("index %d", index);
-	return -ENOSYS;
-}
-
 static int mgmt_cancel_resolve_name(int index, bdaddr_t *bdaddr)
 {
 	char addr[18];
@@ -601,29 +606,17 @@ static int mgmt_write_eir_data(int index, uint8_t *data)
 static int mgmt_read_bdaddr(int index, bdaddr_t *bdaddr)
 {
 	char addr[18];
+	struct controller_info *info = &controllers[index];
 
-	ba2str(bdaddr, addr);
+	ba2str(&info->bdaddr, addr);
 	DBG("index %d addr %s", index, addr);
 
-	return -ENOSYS;
-}
+	if (!info->valid)
+		return -ENODEV;
 
-static int mgmt_set_event_mask(int index, uint8_t *events, size_t count)
-{
-	DBG("index %d", index);
-	return -ENOSYS;
-}
+	bacpy(bdaddr, &info->bdaddr);
 
-static int mgmt_write_inq_mode(int index, uint8_t mode)
-{
-	DBG("index %d mode %u", index, mode);
-	return -ENOSYS;
-}
-
-static int mgmt_read_inq_tx_pwr(int index)
-{
-	DBG("index %d", index);
-	return -ENOSYS;
+	return 0;
 }
 
 static int mgmt_block_device(int index, bdaddr_t *bdaddr)
@@ -654,14 +647,33 @@ static int mgmt_get_conn_list(int index, GSList **conns)
 
 static int mgmt_read_local_version(int index, struct hci_version *ver)
 {
+	struct controller_info *info = &controllers[index];
+
 	DBG("index %d", index);
-	return -ENOSYS;
+
+	if (!info->valid)
+		return -ENODEV;
+
+	memset(ver, 0, sizeof(*ver));
+	ver->manufacturer = info->manufacturer;
+	ver->hci_ver = info->hci_ver;
+	ver->hci_rev = info->hci_rev;
+
+	return 0;
 }
 
 static int mgmt_read_local_features(int index, uint8_t *features)
 {
+	struct controller_info *info = &controllers[index];
+
 	DBG("index %d", index);
-	return -ENOSYS;
+
+	if (!info->valid)
+		return -ENODEV;
+
+	memcpy(features, info->features, 8);
+
+	return 0;
 }
 
 static int mgmt_read_local_ext_features(int index)
@@ -670,12 +682,6 @@ static int mgmt_read_local_ext_features(int index)
 	return -ENOSYS;
 }
 
-static int mgmt_init_ssp_mode(int index, uint8_t *mode)
-{
-	DBG("index %d", index);
-	return -ENOSYS;
-}
-
 static int mgmt_read_link_policy(int index)
 {
 	DBG("index %d", index);
@@ -698,8 +704,7 @@ static int mgmt_remove_bonding(int index, bdaddr_t *bdaddr)
 	return -ENOSYS;
 }
 
-static int mgmt_request_authentication(int index, uint16_t handle,
-							uint8_t *status)
+static int mgmt_request_authentication(int index, uint16_t handle)
 {
 	DBG("index %d handle %u", index, handle);
 	return -ENOSYS;
@@ -751,12 +756,6 @@ static int mgmt_read_scan_enable(int index)
 	return -ENOSYS;
 }
 
-static int mgmt_read_ssp_mode(int index)
-{
-	DBG("index %d", index);
-	return -ENOSYS;
-}
-
 static int mgmt_write_le_host(int index, uint8_t le, uint8_t simul)
 {
 	DBG("index %d le %u simul %u", index, le, simul);
@@ -797,23 +796,18 @@ static struct btd_adapter_ops mgmt_ops = {
 	.resolve_name = mgmt_resolve_name,
 	.cancel_resolve_name = mgmt_cancel_resolve_name,
 	.set_name = mgmt_set_name,
-	.read_name = mgmt_read_name,
 	.set_class = mgmt_set_class,
 	.set_fast_connectable = mgmt_fast_connectable,
 	.read_clock = mgmt_read_clock,
 	.get_conn_handle = mgmt_conn_handle,
 	.write_eir_data = mgmt_write_eir_data,
 	.read_bdaddr = mgmt_read_bdaddr,
-	.set_event_mask = mgmt_set_event_mask,
-	.write_inq_mode = mgmt_write_inq_mode,
-	.read_inq_tx_pwr = mgmt_read_inq_tx_pwr,
 	.block_device = mgmt_block_device,
 	.unblock_device = mgmt_unblock_device,
 	.get_conn_list = mgmt_get_conn_list,
 	.read_local_version = mgmt_read_local_version,
 	.read_local_features = mgmt_read_local_features,
 	.read_local_ext_features = mgmt_read_local_ext_features,
-	.init_ssp_mode = mgmt_init_ssp_mode,
 	.read_link_policy = mgmt_read_link_policy,
 	.disconnect = mgmt_disconnect,
 	.remove_bonding = mgmt_remove_bonding,
@@ -823,7 +817,6 @@ static struct btd_adapter_ops mgmt_ops = {
 	.passkey_reply = mgmt_passkey_reply,
 	.get_auth_info = mgmt_get_auth_info,
 	.read_scan_enable = mgmt_read_scan_enable,
-	.read_ssp_mode = mgmt_read_ssp_mode,
 	.write_le_host = mgmt_write_le_host,
 	.get_remote_version = mgmt_get_remote_version,
 	.encrypt_link = mgmt_encrypt_link,
